# Security policy

## Supported versions

| Version       | Supported          |
| ------------- | ------------------ |
| 0.1           | :white_check_mark: |
| < 0.1         | :x:                |

## Reporting a vulnerability

Please report security vulnerabilities by email to [parsipy@openscilab.com](mailto:parsipy@openscilab.com "parsipy@openscilab.com").

If the security vulnerability is accepted, a dedicated bugfix release will be issued as soon as possible (depending on the complexity of the fix).